QR decomposition, constraining the R matrix to have non-negative diagonal entries.
qr2(X)Q An \(n\) by \(p\) matrix with orthonormal columns.
R A \(p\) by \(p\) upper-triangular matrix with non-negative
diagonal elements.
A matrix of dimension \(n\) by \(p\) where \(n \ge p\)
David Gerard.
This function is almost a wrapper for qr(), qr.R(), and
qr.Q(), except it constrains the diagonal elements of R to be
non-negative. If X is full rank with fewer columns than rows, then
this is sufficient to gaurantee uniqueness of the QR decomposition
(Proposition 5.2 of
Eaton (1983)).