Given a vector p, random_ortho will generate a list
ortho_list such that ortho_list[[i]] is a matrix with row and
column dimensions p[[i]] and is drawn from the uniform (Haar)
distribution over the space of orthogonal matrices.
random_ortho(p)ortho_list A list of orthogonal matrices whose dimensions are
given in p.
A vector of dimensions for the matrices.
David Gerard.
This function is primarily used by multiway_takemura in its
averaging over uniformly minimum risk equivariant estimators under rotations
of the data array.
multiway_takemura.