Phi_inv.Samples an upper triangular Cholesky square root of a mirror-Wishart distributed random variable.
sample_right_wishart(nu, V)C An upper triangular matrix such that C %*% t(C) is
a sample from the mirror-Wishart(nu, V ^ -1) distribution.
A numeric. The degrees of freedom in the mirror-Wishart.
A matrix. The inverse of the scale matrix in the mirror-Wishart.
David Gerard.
Let \(X\) be mirror-Wishart(\(\nu\), \(V^-1\)). Then This code
returns an upper triangular \(C\) where \(X = CC'\). This
function is used primarily during the Gibbs updates of the inverse
of the lower triangular Cholesky square root of the component
covariance matrices in equi_mcmc.
Gerard, D., & Hoff, P. (2015). Equivariant minimax dominators of the MLE in the array normal model. Journal of Multivariate Analysis, 137, 32-49. tools:::Rd_expr_doi("10.1016/j.jmva.2015.01.020")
equi_mcmc, rmirror_wishart.